> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Compass 2 Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on PIC32
---
#include <stdint.h>
#include "compass2_hw.h"

sbit COMPASS2_CS at RC2_bit;
sbit COMPASS2_CS_DIR at TRISC2_bit;
sbit RST at RC1_bit;
sbit RST_DIR at TRISC1_bit;

void system_setup( bus_mode_t mode, uint8_t addr );

float mRes;                  // scale resolutions per LSB for the sensors
uint8_t asax, asay, asaz;
float adjusted_ASAX, adjusted_ASAY, adjusted_ASAZ;
float heading, adjusted_MX, adjusted_MY, adjusted_MZ, magbias[3];
int16_t mx, my, mz;
char text[20] = { 0 };

void system_setup( bus_mode_t mode, uint8_t addr )
{

         // GPIOs
         COMPASS2_CS_DIR = 0;
         TRISD = 0;             // Initialize PORTG as output
         LATD = 0;              // Set PORTA to zero

         //GPIOs
         RST_DIR = 0;

         //Toggle Reset Pin
         RST = 0;
         Delay_ms(50);
         RST = 1;
         Delay_ms(200);


        // UART
        UART2_Init( 9600 );
        UART2_Write_Text( "UART Initialized\r\n" );

        // I2C
        I2C2_Init( 100000 );
        Delay_ms(200);
        UART2_Write_Text( "I2C Initialized\r\n" );


        // Compass 2
        compass2_hw_init( addr, mode );
        compass2_set_mode( MODE_CONT_1 );
        compass2_set_scale_factor( RES_16 );

        UART2_Write_Text( "Compass2 Setup Completed..\r\n" );
}

```

```

void main()
{
        // Local Declarations
        uint8_t address = 0x0F;
        bus_mode_t my_mode = I2C;
        float heading = 0;
        char uart_text[5] = { 0 };

        system_setup( my_mode, address );

        while(1)
        {
            compass2_get_all_values( &mx, &my, &mz );
            heading = compass2_get_compass_heading( mx, my, mz );

            if( heading < 0 )
                heading += 360;

            UART2_Write_Text( "Heading: " );
            FloatToStr( heading, text );
            UART2_Write_Text( text );
            UART2_Write_Text( " Direction: " );

            if( heading >= 330 || heading <= 30 )
            {
                uart_text[0] = 'N';
                uart_text[1] = '\n';
            }
            else if( heading >= 300 && heading <= 330 )
            {
                uart_text[0] = 'N';
                uart_text[1] = 'W';
                uart_text[2] = '\n';
            }
            else if( heading >= 240 && heading <= 300)
            {
                uart_text[0] = 'W';
                uart_text[1] = '\n';
            }
            else if( heading >= 210 && heading <= 240 )
            {
                uart_text[0] = 'S';
                uart_text[1] = 'W';
                uart_text[2] = '\n';
            }
            else if( heading <= 210 && heading >= 150 )
            {
                uart_text[0] = 'S';
                uart_text[1] = '\n';
            }
            else if( heading <= 150 && heading >= 120 )
            {
                uart_text[0] = 'S';
                uart_text[1] = 'E';
                uart_text[2] = '\n';
            }
            else if( heading <= 120 && heading >= 60 )
            {
                uart_text[0] = 'E';
                uart_text[1] = '\n';
            }
            else if( heading <= 60 && heading >= 30 )
            {
                uart_text[0] = 'N';
                uart_text[1] = 'E';
                uart_text[2] = '\n';
            }

            UART2_Write_Text( uart_text );
            UART2_Write_Text( "\r\n" );

            Delay_ms(100);
        }

}

```

