#include <stdint.h>
#include "compass2_hw.h"

sbit COMPASS2_CS at RC2_bit;
sbit COMPASS2_CS_DIR at TRISC2_bit;
sbit COMPASS2_RST at RC1_bit;
sbit COMPASS2_RST_DIR at TRISC1_bit;

void system_setup( bus_mode_t mode, uint8_t addr );

float mRes;                  // scale resolutions per LSB for the sensors
uint8_t asax, asay, asaz;
float adjusted_ASAX, adjusted_ASAY, adjusted_ASAZ;
float heading, adjusted_MX, adjusted_MY, adjusted_MZ, magbias[3];
int16_t mx, my, mz;
char text[20] = { 0 };

void main()
{
        // Local Declarations
        uint8_t address = 0x0F;
        bus_mode_t my_mode = I2C;
        float heading = 0;
        char uart_text[5] = { 0 };

        system_setup( my_mode, address );

        UART2_Write_Text( "\r\n----Please Hold The Click Level----\r\n\r\n\r\n" );
        Delay_ms(2000);

        while (1)
        {
             while( !compass2_get_data_ready() );   //Wait for data to be ready

             compass2_get_all_values( &mx, &my, &mz );               //Get x,y,z values for heading
             heading = compass2_get_compass_heading( mx, my, mz );   //Get heading

             FloatToStr( heading, uart_text );
             UART2_Write_Text( "Heading : " );
             UART2_Write_Text( uart_text );
             UART2_Write_Text( "\r\n" );
        }


}

void system_setup( bus_mode_t mode, uint8_t addr )
{
         uint8_t my_address = 0;

                // GPIOs
         COMPASS2_CS_DIR = 0;
         TRISD = 0;             // Initialize PORTG as output
         LATD = 0;              // Set PORTA to zero

             //GPIOs
         COMPASS2_RST_DIR = 0;

         //Toggle Reset Pin
         COMPASS2_RST = 0;
         Delay_ms(50);
         COMPASS2_RST = 1;
         Delay_ms(200);


        // UART
        UART2_Init( 9600 );
        UART2_Write_Text( "UART Initialized\r\n" );

        // I2C
        I2C2_Init( 100000 );
        Delay_ms(200);
        UART2_Write_Text( "I2C Initialized\r\n" );


        // Compass 2
        UART2_Write_Text( "Getting Device ID..." );
        compass2_hw_init( addr, mode );
        UART2_Write_Text( "Compass Initialized\r\n" );

        // Device Address
        my_address = compass2_get_device_id();
        IntToStr( my_address, text );
        UART2_Write_Text( text );
        UART2_Write_Text( "\r\n" );

        // Continuous Measurment Mode / Output Res
        compass2_set_output_res( RES_16 );
        compass2_set_mode( MODE_CONT_2 );

        UART2_Write_Text( "Compass2 Setup Completed..\r\n" );


}